EventSubscription class

Can be used to cancel the given subscription of a EventHandler.

Constructors

EventSubscription(CancelCallback _unsubscribe)
Creates a new EventSubscription that will trigger the _unsubscribe on cancel.

Properties

hashCode → int
The hash code for this object.
no setterinherited
isCanceled → bool
Whether the current subscription has been canceled.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancel() → void
Cancels the current subscription.
doOnCancel(CancelCallback callback) → void
Adds a callback callback that will be invoked when cancel is called.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited