QueryHandler<TResponse extends Object, TQuery extends Query<TResponse>> class abstract interface

Query handler for TQuery.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

handle(TQuery request) → FutureOr<TResponse>
Handles the given request.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited